==> apache-fory-0.12.3-src.tar.gz: apache-fory-0.12.3-src/integration_tests/graalvm_tests/src/main/java/org/apache/fory/graalvm/CompatibleExample.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.fory.graalvm;

import org.apache.fory.Fory;
import org.apache.fory.config.CompatibleMode;

public class CompatibleExample {
  static Fory fory;

  static {
    fory = createFory();
  }

  private static Fory createFory() {
    Fory fory =
        Fory.builder()
            .requireClassRegistration(true)
            .withCompatibleMode(CompatibleMode.COMPATIBLE)
            .withScopedMetaShare(false)
            .build();
    // register and generate serializer code.
    fory.register(Foo.class, true);
    return fory;
  }

  public static void main(String[] args) {
    System.out.println("CompatibleExample started");
    Example.test(fory);
    System.out.println("CompatibleExample succeed 1/2");
    // Test new created Fory at runtime
    fory = createFory();
    Example.test(fory);
    System.out.println("CompatibleExample succeed");
  }
}

==> apache-fory-v0.13.0-src.tar.gz: apache-fory-v0.13.0-src/integration_tests/graalvm_tests/src/main/java/org/apache/fory/graalvm/CompatibleExample.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.fory.graalvm;

import org.apache.fory.Fory;
import org.apache.fory.config.CompatibleMode;

public class CompatibleExample {
  static Fory fory;

  static {
    fory = createFory();
  }

  private static Fory createFory() {
    Fory fory =
        Fory.builder()
            .requireClassRegistration(true)
            .withCompatibleMode(CompatibleMode.COMPATIBLE)
            .withScopedMetaShare(false)
            .build();
    // register and generate serializer code.
    fory.register(Foo.class);
    fory.ensureSerializersCompiled();
    return fory;
  }

  public static void main(String[] args) {
    System.out.println("CompatibleExample started");
    Example.test(fory);
    System.out.println("CompatibleExample succeed 1/2");
    // Test new created Fory at runtime
    fory = createFory();
    Example.test(fory);
    System.out.println("CompatibleExample succeed");
  }
}
